==> pathena-0.3.3.tgz: .pathena/pytk_client/client_messages.py <==
display_messages = \
    {
     'edit_prefs' :
     "Edit the preference values below, then select the Save button.  " 
     "New preferences will take effect the next time you " 
     "start Pathena Client.  Select Restore Defaults if you need to " 
     "recover the original values, then select Save." ,

     'customize_source' :
     "Edit the source-file type specifications below, then select the "
     "Save button. The new source file types you create will be "
     "available the next time you start Pathena Client." ,
     
     'edit_profile' :
     "Edit the profile below, then select the Save button to rewrite "
     "it using the same file name. Select the Save As button to choose a "
     "new name for the profile. The new profile will be available for "
     "use immediately. " ,
     
     'internal_error' :
     "Unfortunately, an internal error has been detected, " 
     "which probably means the client or server contains a latent bug. " 
     "If you would be kind enough to report the problem, " 
     "the authors can provide corrections in a future version.  " 
     "If this event is followed by unusual behavior, "
     "it would be wise to " 
     "restart Pathena Client before proceeding with your work. " 
     "Sorry for any inconvenience." ,

     'display_stats' :
     "The following report displays various statistics of the "
     "full-text index. It shows which "
     "words have been indexed and how often they occur. Only the "
     "highest ranking words are displayed initially. You can choose "
     "to see the least frequent words instead. You also can see counts "
     "for more words by adjusting the limit and redisplaying "
     "(will be slow for large limits). " ,

     'about_stat_update' :
     "These statistics are updated only after a full indexing operation. " ,

     'index_files' :
     "The Pathena database server can index a subset of "
     "your file system based on the profiles stored in "
     "~/.pathena/profiles. After profile selection, the server "
     "will scan the directories specified in the profile, then "
     "report the number of files to be indexed. Path name and file "
     "content indexing will then be started as a background job. "
     "For moderate to large profiles, this operation can take "
     "many minutes to complete. Progress will be reported."
     "\n\n"
     "You may choose either full or 'quick' indexing. "
     "Quick indexing defers various tasks for updating statistics, "
     "rebuilding internal data structures, "
     "and purging old information from the database. It is more "
     "appropriate for small profiles or when the selected files "
     "are largely unchanged since the previous indexing run. "
     "Full indexing is recommended for overnight runs." ,

     'background_indexing' :
     "A file indexing job will be launched and will run "
     "in the background until completed. This job can make heavy "
     "use of your system's resources. It can keep your disk drive(s) "
     "quite busy and consume all available processing time. You can choose "
     "a slower pace by selecting a delay value using the slider "
     "below. Indexing will pause for this duration after "
     "each work segment of 100 ms or so."
     "\n\n"
     "The indexing process runs with low priority so it is normally "
     "unnecessary to throttle its speed. An exception might be made for "
     "laptops, though, where disk drives are more fragile than those of "
     "desktops. Laptop drives are not designed for high duty cycle "
     "operation. A wise precaution would be to run long indexing jobs "
     "on laptops at low to moderate intensity by choosing a rest period "
     "of 100 ms or more." ,

     'indexing_in_progress' :
     "A file indexing job for profile '%s' has been launched and will run "
     "in the background until completed. Progress will be reported below, "
     "updated every second. " ,   # % profile

     'schedule_indexing' :
     "Pathena (re)indexing can be performed in batch mode and initiated "
     "on a periodic basis using the 'cron' service (Unix family operating "
     "systems). If you would like to update your Pathena index regularly "
     "(e.g., nightly), simply add a scheduling entry to your cron table, "
     "which typically can be done using a command such as 'crontab -e'."
     "\n\n"
     "To help with this process, you may create one or more entries below "
     "using the Insert buttons to select either full or "
     "'quick' indexing. Each candidate entry will cause cron to run the "
     "indexer daily at 3:15 AM using all of your profiles. Edit as "
     "needed to modify the schedule or profile list."
     "\n\n"
     "Quick indexing defers various tasks for updating statistics, "
     "rebuilding internal data structures, "
     "and purging old information from the database. "
     "If quick indexing is used, be sure to include, in addition, "
     "a full indexing entry that runs at least weekly. If file deletions "
     "occur often, frequent scheduling of full indexing is advised."
     "\n\n"
     "After adjusting the entries to your preferences, copy them to the "
     "clipboard using the Copy button below, then paste them into "
     "your crontab. " ,

     'crontab_added' :
     "A crontab entry has been created. You should check it by issuing "
     "the shell command 'crontab -l'. You may edit this entry anytime "
     "using the command 'crontab -e' to change the schedule or to add "
     "or subtract profiles." ,

     'clear_database' :
     "Clearing the Pathena database will remove all of the currently "
     "stored information on path names and file content. "
     "Be sure this is what you intend before proceeding. "
     "This operation cannot be undone.  You will need to reindex "
     "the file system to recreate this data." ,

     'display_file_types' :
     "The following list shows which file types are registered for "
     "full text indexing. Regular file types are recognized by the "
     "extension part of their file names. A file type name is written "
     "in the form <genus>/<species>." ,

     'missing_cmds_backup' :
     "Some file types require text conversion programs or OS commands that "
     "might not reside on your system. The following list shows "
     "which file types have missing commands. "
     "As a backup, the OS command 'strings' will be used to convert "
     "these file types. "
     "For best results, consider installing the missing software." ,

     'missing_file_cmds' :
     "Some file types require text conversion programs or OS commands that "
     "might not reside on your system.  The following list shows "
     "which file types have missing commands. "
     "If you would like to index file types on this list, "
     "you will need to install the corresponding software." ,

     'display_file_cmds_present' :
     "All necessary text conversion programs and OS commands for indexing "
     "these file types have been found on your system." ,

     'invoke_shell_command_file' :
     "Enter a command string below. Include '%s' wherever you want the path "
     "name to be inserted.  Omitting %s causes the file contents to be "
     "piped to the command. " ,

     'invoke_shell_command_direc' :
     "Enter a command string below. It will be preceded by a 'cd' "
     "to the target directory. "
     "You may then use '.' to refer to the directory. " ,

     'invoke_shell_command_paths' :
     "Enter a command string below. Include '%s' wherever you want the list "
     "of path names to be inserted. " ,

     'edit_path_list' :
     "Select path names from either list to move to the other. Both "
     "lists will be saved so hidden paths can be retrieved later." ,
     
     'explain_terminal' :
     "If menu item Open Terminal Window on Paths is selected, "
     "the new terminal will be passed a list of path names as "
     "shell parameters.  This means they will be available as "
     "positional parameters $1, $2, etc., or through the special "
     "parameter '$*'.  Shell commands such as 'ls -l $*' should be "
     "expanded accordingly."
     "\n\n"
     "If any path name contains the space character, the shell "
     "will likely parse the path as two or more words.  If this happens, "
     "using the 'eval' command should correct the problem.  For "
     "example, enter the command as 'eval ls -l $*'. " ,
     
     }


dialog_messages = \
    {
     'confirm_indexing_cancel' :
     ('Indexing files',
      "Cancellation will terminate the indexing process currently underway "
      "and abort the remainder of the indexing job. "
      "Any files already indexed will remain in the database. "
      "Do you wish to proceed with cancellation? " ) ,
    }


error_messages = \
    {
     'db_server_down' :
     ('Pathena Client start-up',
      "A connection to the Pathena database server was not established. "
      "It's possible an earlier instance of the server was not shut down."
      "\n\n"
      "Try starting Pathena Client again. If problems persist, run "
      "'tail ~/.pathena/log/pg_server' for instructions on clearing "
      "the problem." ) ,

     'missing_font_family' :
     ('Pathena Client start-up',
      "None of the font families from the group %s could be found. "
      "There might be something wrong with your "
      "Tk installation. ") ,    ## % family_list
      
     'bad_user_directory' :
     ('Pathena Client start-up',
      "It was not possible to locate or create the "
      "expected user directory while starting the client application.  "
      "It could be that Pathena Client is "
      "incompatible with your computer or operating system platform.  "
      "Proceed with caution.") ,

     'bad_preferences' :
     ('Pathena Client preferences',
      "While reading the preferences file, an error was detected " 
      "for preference value '%s'.  " 
      "Select 'Preferences' from the Edit menu to correct " 
      "the problem.  In the meantime, "
      "a default value will be used.") ,     ## % preference_load_error
      
     }


warning_messages = \
    {

     }

==> pathena-0.3.4.tgz: .pathena/pytk_client/client_messages.py <==
display_messages = \
    {
     'edit_prefs' :
     "Edit the preference values below, then select the Save button.  " 
     "New preferences will take effect the next time you " 
     "start Pathena Client.  Select Restore Defaults if you need to " 
     "recover the original values, then select Save." ,

     'customize_source' :
     "Edit the source-file type specifications below, then select the "
     "Save button. The new source file types you create will be "
     "available the next time you start Pathena Client." ,
     
     'edit_profile' :
     "Edit the profile below, then select the Save button to rewrite "
     "it using the same file name. Select the Save As button to choose a "
     "new name for the profile. The new profile will be available for "
     "use immediately. " ,
     
     'internal_error' :
     "Unfortunately, an internal error has been detected, " 
     "which probably means the client or server contains a latent bug. " 
     "If you would be kind enough to report the problem, " 
     "the authors can provide corrections in a future version.  " 
     "If this event is followed by unusual behavior, "
     "it would be wise to " 
     "restart Pathena Client before proceeding with your work. " 
     "Sorry for any inconvenience." ,

     'display_stats' :
     "The following report displays various statistics of the "
     "full-text index. It shows which "
     "words have been indexed and how often they occur. Only the "
     "highest ranking words are displayed initially. You can choose "
     "to see the least frequent words instead. You also can see counts "
     "for more words by adjusting the limit and redisplaying "
     "(will be slow for large limits). " ,

     'about_stat_update' :
     "These statistics are updated only after a full indexing operation. " ,

     'index_files' :
     "The Pathena database server can index a subset of "
     "your file system based on the profiles stored in "
     "~/.pathena/profiles. After profile selection, the server "
     "will scan the directories specified in the profile, then "
     "report the number of files to be indexed. Path name and file "
     "content indexing will then be started as a background job. "
     "For moderate to large profiles, this operation can take "
     "many minutes to complete. Progress will be reported."
     "\n\n"
     "You may choose either full or 'quick' indexing. "
     "Quick indexing defers various tasks for updating statistics, "
     "rebuilding internal data structures, "
     "and purging old information from the database. It is more "
     "appropriate for small profiles or when the selected files "
     "are largely unchanged since the previous indexing run. "
     "Full indexing is recommended for overnight runs." ,

     'background_indexing' :
     "A file indexing job will be launched and will run "
     "in the background until completed. This job can make heavy "
     "use of your system's resources. It can keep your disk drive(s) "
     "quite busy and consume all available processing time. You can choose "
     "a slower pace by selecting a delay value using the slider "
     "below. Indexing will pause for this duration after "
     "each work segment of 100 ms or so."
     "\n\n"
     "The indexing process runs with low priority so normally it is "
     "unnecessary to throttle its speed. An exception might be made for "
     "laptops, though, where disk drives are more fragile than those of "
     "desktops. Laptop drives are not designed for high duty cycle "
     "operation. A wise precaution would be to run long indexing jobs "
     "on laptops at low to moderate intensity by choosing a rest period "
     "of 100 ms or more." ,

     'indexing_in_progress' :
     "A file indexing job for profile '%s' has been launched and will run "
     "in the background until completed. Progress will be reported below, "
     "updated every second. " ,   # % profile

     'schedule_indexing' :
     "Pathena (re)indexing can be performed in batch mode and initiated "
     "on a periodic basis using the 'cron' service (Unix family operating "
     "systems). If you would like to update your Pathena index regularly "
     "(e.g., nightly), simply add a scheduling entry to your cron table, "
     "which typically can be done using a command such as 'crontab -e'."
     "\n\n"
     "To help with this process, you may create one or more entries below "
     "using the Insert buttons to select either full or "
     "'quick' indexing. Each candidate entry will cause cron to run the "
     "indexer daily at 3:15 AM using all of your profiles. Edit as "
     "needed to modify the schedule or profile list."
     "\n\n"
     "Quick indexing defers various tasks for updating statistics, "
     "rebuilding internal data structures, "
     "and purging old information from the database. "
     "If quick indexing is used, be sure to include, in addition, "
     "a full indexing entry that runs at least weekly. If file deletions "
     "occur often, frequent scheduling of full indexing is advised."
     "\n\n"
     "After adjusting the entries to your preferences, copy them to the "
     "clipboard using the Copy button below, then paste them into "
     "your crontab. " ,

     'crontab_added' :
     "A crontab entry has been created. You should check it by issuing "
     "the shell command 'crontab -l'. You may edit this entry anytime "
     "using the command 'crontab -e' to change the schedule or to add "
     "or subtract profiles." ,

     'clear_database' :
     "Clearing the Pathena database will remove all of the currently "
     "stored information on path names and file content. "
     "Be sure this is what you intend before proceeding. "
     "This operation cannot be undone.  You will need to reindex "
     "the file system to recreate this data." ,

     'display_file_types' :
     "The following list shows which file types are registered for "
     "full text indexing. Regular file types are recognized by the "
     "extension part of their file names. A file type name is written "
     "in the form <genus>/<species>." ,

     'missing_cmds_backup' :
     "Some file types require text conversion programs or OS commands that "
     "might not reside on your system. The following list shows "
     "which file types have missing commands. "
     "As a backup, the OS command 'strings' will be used to convert "
     "these file types. "
     "For best results, consider installing the missing software." ,

     'missing_file_cmds' :
     "Some file types require text conversion programs or OS commands that "
     "might not reside on your system.  The following list shows "
     "which file types have missing commands. "
     "If you would like to index file types on this list, "
     "you will need to install the corresponding software." ,

     'display_file_cmds_present' :
     "All necessary text conversion programs and OS commands for indexing "
     "these file types have been found on your system." ,

     'invoke_shell_command_file' :
     "Enter a command string below. Include '%s' wherever you want the path "
     "name to be inserted.  Omitting %s causes the file contents to be "
     "piped to the command. " ,

     'invoke_shell_command_direc' :
     "Enter a command string below. It will be preceded by a 'cd' "
     "to the target directory. "
     "You may then use '.' to refer to the directory. " ,

     'invoke_shell_command_paths' :
     "Enter a command string below. Include '%s' wherever you want the list "
     "of path names to be inserted. " ,

     'edit_path_list' :
     "Select path names from either list to move to the other. Both "
     "lists will be saved so hidden paths can be retrieved later." ,
     
     'explain_terminal' :
     "If menu item Open Terminal Window on Paths is selected, "
     "the new terminal will be passed a list of path names as "
     "shell parameters.  This means they will be available as "
     "positional parameters $1, $2, etc., or through the special "
     "parameter '$*'.  Shell commands such as 'ls -l $*' should be "
     "expanded accordingly."
     "\n\n"
     "If any path name contains the space character, the shell "
     "will likely parse the path as two or more words.  If this happens, "
     "using the 'eval' command should correct the problem.  For "
     "example, enter the command as 'eval ls -l $*'. " ,
     
     }


dialog_messages = \
    {
     'confirm_indexing_cancel' :
     ('Indexing files',
      "Cancellation will terminate the indexing process currently underway "
      "and abort the remainder of the indexing job. "
      "Any files already indexed will remain in the database. "
      "Do you wish to proceed with cancellation? " ) ,
    }


error_messages = \
    {
     'db_server_down' :
     ('Pathena Client start-up',
      "A connection to the Pathena database server was not established. "
      "It's possible an earlier instance of the server was not shut down."
      "\n\n"
      "Try starting Pathena Client again. If problems persist, run "
      "'tail ~/.pathena/log/pg_server' for possible instructions on "
      "clearing the problem. Typically, all that's needed is to "
      "delete the file '~/.pathena/data/postmaster.pid'." ) ,

     'missing_font_family' :
     ('Pathena Client start-up',
      "None of the font families from the group %s could be found. "
      "There might be something wrong with your "
      "Tk installation. ") ,    ## % family_list
      
     'bad_user_directory' :
     ('Pathena Client start-up',
      "It was not possible to locate or create the "
      "expected user directory while starting the client application.  "
      "It could be that Pathena Client is "
      "incompatible with your computer or operating system platform.  "
      "Proceed with caution.") ,

     'bad_preferences' :
     ('Pathena Client preferences',
      "While reading the preferences file, an error was detected " 
      "for preference value '%s'.  " 
      "Select 'Preferences' from the Edit menu to correct " 
      "the problem.  In the meantime, "
      "a default value will be used.") ,     ## % preference_load_error
      
     }


warning_messages = \
    {

     }
